@@ -181,6 +181,29 @@ int XLALSimIMRPhenomCGenerateFD(
     const REAL8 distance               /**< distance of source (m) */
 );
 
+/**
+ * Driver routine to compute the spin-aligned, inspiral-merger-ringdown
+ * phenomenological waveform IMRPhenomD in the frequency domain.
+ *
+ * Reference:
+ * - Waveform: Eq.
+ * - Coefficients: Eq. and Table
+ *
+ * All input parameters should be in SI units. Angles should be in radians.
+ */
+int XLALSimIMRPhenomDGenerateFD(
+    COMPLEX16FrequencySeries **htilde, /**< FD waveform */
+    const REAL8 phi0,                  /**< orbital phase at peak (rad) */
+    const REAL8 deltaF,                /**< sampling interval (Hz) */
+    const REAL8 m1_SI,                 /**< mass of companion 1 (kg) */
+    const REAL8 m2_SI,                 /**< mass of companion 2 (kg) */
+    const REAL8 chi1,                  /**< aligned-spin of companion 1 */
+    const REAL8 chi2,                  /**< aligned-spin of companion 2 */
+    const REAL8 f_min,                 /**< starting GW frequency (Hz) */
+    const REAL8 f_max,                 /**< end frequency; 0 defaults to ringdown cutoff freq */
+    const REAL8 distance               /**< distance of source (m) */
+);
+
 /**
  * Driver routine to compute the plus and cross polarizations for the IMRPhenomP model
  * for precessing binaries in the frequency domain.
@@ -376,7 +399,7 @@ int XLALSimIMRSpinEOBWaveform(
  * See CQG 31 195010, 2014, arXiv:1402.4146 for details.
  */
 
-int XLALSimIMRSEOBNRv1ROMSingleSpin(
+int XLALSimIMRSEOBNRv1ROMEffectiveSpin(
     struct tagCOMPLEX16FrequencySeries **hptilde, /**< Output: Frequency-domain waveform h+ */
     struct tagCOMPLEX16FrequencySeries **hctilde, /**< Output: Frequency-domain waveform hx */
     REAL8 phiRef,                                 /**< Phase at reference frequency */
@@ -392,7 +415,7 @@ int XLALSimIMRSEOBNRv1ROMSingleSpin(
 );
 
 /** Compute waveform in LAL format at specified frequencies */
-int XLALSimIMRSEOBNRv1ROMSingleSpinFrequencySequence(
+int XLALSimIMRSEOBNRv1ROMEffectiveSpinFrequencySequence(
     struct tagCOMPLEX16FrequencySeries **hptilde, /**< Output: Frequency-domain waveform h+ */
     struct tagCOMPLEX16FrequencySeries **hctilde, /**< Output: Frequency-domain waveform hx */
     const REAL8Sequence *freqs,                   /**< Frequency points at which to evaluate the waveform (Hz) */
@@ -442,7 +465,7 @@ int XLALSimIMRSEOBNRv1ROMDoubleSpinFrequencySequence(
  * See CQG 31 195010, 2014, arXiv:1402.4146 for details.
  */
 
-int XLALSimIMRSEOBNRv2ROMSingleSpin(
+int XLALSimIMRSEOBNRv2ROMEffectiveSpin(
     struct tagCOMPLEX16FrequencySeries **hptilde, /**< Output: Frequency-domain waveform h+ */
     struct tagCOMPLEX16FrequencySeries **hctilde, /**< Output: Frequency-domain waveform hx */
     REAL8 phiRef,                                 /**< Phase at reference frequency */
@@ -458,7 +481,7 @@ int XLALSimIMRSEOBNRv2ROMSingleSpin(
 );
 
 /** Compute waveform in LAL format at specified frequencies */
-int XLALSimIMRSEOBNRv2ROMSingleSpinFrequencySequence(
+int XLALSimIMRSEOBNRv2ROMEffectiveSpinFrequencySequence(
   struct tagCOMPLEX16FrequencySeries **hptilde, /**< Output: Frequency-domain waveform h+ */
   struct tagCOMPLEX16FrequencySeries **hctilde, /**< Output: Frequency-domain waveform hx */
   const REAL8Sequence *freqs,                   /**< Frequency points at which to evaluate the waveform (Hz) */
@@ -475,7 +498,7 @@ int XLALSimIMRSEOBNRv2ROMSingleSpinFrequencySequence(
  * Compute the time at a given frequency. The origin of time is at the merger.
  * The allowed frequency range for the input is Mf in [0.0001, 0.3].
  */
-int XLALSimIMRSEOBNRv2ROMSingleSpinTimeOfFrequency(
+int XLALSimIMRSEOBNRv2ROMEffectiveSpinTimeOfFrequency(
   REAL8 *t,         /**< Output: time (s) at frequency */
   REAL8 frequency,  /**< Frequency (Hz) */
   REAL8 m1SI,       /**< Mass of companion 1 (kg) */
@@ -487,7 +510,7 @@ int XLALSimIMRSEOBNRv2ROMSingleSpinTimeOfFrequency(
  * Compute the frequency at a given time. The origin of time is at the merger.
  * The frequency range for the output is Mf in [0.0001, 0.3].
  */
-int XLALSimIMRSEOBNRv2ROMSingleSpinFrequencyOfTime(
+int XLALSimIMRSEOBNRv2ROMEffectiveSpinFrequencyOfTime(
   REAL8 *frequency,   /**< Output: Frequency (Hz) */
   REAL8 t,            /**< Time (s) at frequency */
   REAL8 m1SI,         /**< Mass of companion 1 (kg) */
