@@ -184,7 +184,7 @@ int XLALSimInspiralSpinTaylorT5 (
 	LIGOTimeGPS tStart = LIGOTIMEGPSZERO;
 	REAL8TimeSeries *orbPhase=NULL, *V=NULL, *LNhxVec=NULL, *LNhyVec=NULL, *LNhzVec=NULL; 
 	REAL8TimeSeries *S1xVec=NULL, *S1yVec=NULL, *S1zVec=NULL, *S2xVec=NULL, *S2yVec=NULL, *S2zVec=NULL;
-	ark4GSLIntegrator *integrator = NULL;     /* GSL integrator object */
+	LALAdaptiveRungeKutta4Integrator *integrator = NULL;     /* GSL integrator object */
     SpinTaylorT5Params *mParams;
     SpinTaylorT5Params SpinTaylorParameters;
     REAL8 LNh[3], S1[3], S2[3], J[3], Jh[3], Lmag, Jmag, v; 
@@ -536,7 +536,7 @@ static REAL8 XLALdEnergyByFluxSpinPrec(
 			dEbF0 = params->dEbF0NonSpin; 
 			break; 
 		default: 
-            XLALPrintError("XLAL Error - %s: Invalid phase. PN order %s\n", __func__, phaseO);
+            XLALPrintError("XLAL Error - %s: Invalid phase. PN order %d\n", __func__, phaseO);
             XLAL_ERROR(XLAL_EINVAL);
 		break;
     }
@@ -745,7 +745,7 @@ static int computeOrbitalPhase(
 					phi0 = params->phiOrb0NonSpin; 
 					break; 
 				default: 
-					XLALPrintError("XLAL Error - %s: Invalid phase. PN order %s\n", __func__, phaseO);
+					XLALPrintError("XLAL Error - %s: Invalid phase. PN order %d\n", __func__, phaseO);
 					XLAL_ERROR(XLAL_EINVAL);
 				break;
 			}
