@@ -20,6 +20,7 @@
 #include <math.h>
 #include <stdlib.h>
 #include <time.h>
+#include <sys/types.h>
 
 #include <lal/LALConstants.h>
 #include <lal/LALDatatypes.h>
@@ -98,9 +99,9 @@ const char * usage =
 "                             IMRPhenomB\n"
 "                             IMRPhenomC\n"
 "                             IMRPhenomP\n"
-"                             SEOBNRv1_ROM_SingleSpin\n"
+"                             SEOBNRv1_ROM_EffectiveSpin\n"
 "                             SEOBNRv1_ROM_DoubleSpin\n"
-"                             SEOBNRv2_ROM_SingleSpin\n"
+"                             SEOBNRv2_ROM_EffectiveSpin\n"
 "                             SEOBNRv2_ROM_DoubleSpin\n"
 "                             TaylorF2\n"
 "                             SpinTaylorF2\n"
