@@ -206,7 +206,7 @@ static void Test_XLALSimIMRPhenomPCalculateModelParameters(void);
 static void Test_XLALSimIMRPhenomPCalculateModelParameters(void) {
   printf("\n** Test_XLALSimIMRPhenomPCalculateModelParameters: **\n");
 
-  REAL8 eta, chi_eff, chip, thetaJ, phiJ, alpha0;
+  REAL8 eta, chi_eff, chip, thetaJ, alpha0;
 
   REAL8 m1_SI = 10 * LAL_MSUN_SI;
   REAL8 m2_SI = 40 * LAL_MSUN_SI;
@@ -227,8 +227,7 @@ static void Test_XLALSimIMRPhenomPCalculateModelParameters(void) {
       &chip,              /**< Output: Effective spin in the orbital plane */
       &eta,               /**< Output: Symmetric mass-ratio */
       &thetaJ,            /**< Output: Angle between J0 and line of sight (z-direction) */
-      &phiJ,              /**< Output: Angle of J0 in the plane of the sky */
-      &alpha0,            /**< Output: Initial value of alpha angle */
+      &alpha0,            /**< Output: Initial value of alpha angle (azimuthal precession angle) */
       m1_SI,              /**< Mass of companion 1 (kg) */
       m2_SI,              /**< Mass of companion 2 (kg) */
       f_ref,              /**< Reference GW frequency (Hz) */
@@ -246,14 +245,12 @@ static void Test_XLALSimIMRPhenomPCalculateModelParameters(void) {
   REAL8 chi_eff_expected = 0.4378425;
   REAL8 chip_expected = 0.17523825;
   REAL8 thetaJ_expected = 0.298552787;
-  REAL8 phiJ_expected = 0;
   REAL8 alpha0_expected = LAL_PI;
 
   print_difference("eta", eta, eta_expected);
   print_difference("chi_eff", chi_eff, chi_eff_expected);
   print_difference("chip", chip, chip_expected);
   print_difference("thetaJ", thetaJ, thetaJ_expected);
-  print_difference("phiJ", phiJ, phiJ_expected);
   print_difference("alpha0", alpha0, alpha0_expected);
 
   //const REAL8 eps = DBL_EPSILON;
@@ -264,7 +261,6 @@ static void Test_XLALSimIMRPhenomPCalculateModelParameters(void) {
     && approximatelyEqual(chi_eff,  chi_eff_expected, eps)
     && approximatelyEqual(chip,     chip_expected, eps)
     && approximatelyEqual(thetaJ,   thetaJ_expected, eps)
-    && approximatelyEqual(phiJ,     phiJ_expected, eps)
     && approximatelyEqual(alpha0,   alpha0_expected, eps)
     && "Test_XLALSimIMRPhenomPCalculateModelParameters()"
   );
@@ -304,7 +300,7 @@ static void Test_PhenomC(void) {
   printf("LAL_MRSUN_SI, LAL_MTSUN_SI, LAL_PC_SI: %g\t%g\t%g\n",LAL_MRSUN_SI, LAL_MTSUN_SI, LAL_PC_SI);
   prC("hPC", hPC);
 
-  COMPLEX16 hPC_expected = -4.08272e-23 - I * 8.89604e-23;
+  COMPLEX16 hPC_expected = -4.08291e-23 - I * 8.89596e-23;
 
   const REAL8 eps = 1e-5;
 
@@ -349,8 +345,9 @@ static void Test_PhenomPCore(void) {
   Y2m.Y22  = XLALSpinWeightedSphericalHarmonic(ytheta, yphi, -2, 2,  2);
 
   COMPLEX16 hp, hc;
+  REAL8 phasing;
   REAL8 fHz = 40.6051; // Mf = 0.01 for M=50Msun
-  int ret = PhenomPCore(
+  int ret = PhenomPCoreOneFrequency(
     fHz,                     /**< frequency (Hz) */
     0.16,                    /**< symmetric mass ratio */
     0.45,                    /**< dimensionless effective total aligned spin */
@@ -362,14 +359,16 @@ static void Test_PhenomPCore(void) {
     &angcoeffs,              /**< struct with PN coeffs for the NNLO angles */
     &Y2m,                    /**< struct of l=2 spherical harmonics of spin weight -2 */
     0,0,
-    &hp,                     /**< output: \tilde h_+ */
-    &hc);                    /**< output: \tilde h_+ */
+    &hp,                     /**< output: \f$\tilde h_+\f$ */
+    &hc,                     /**< output: \f$\tilde h_+\f$ */
+    &phasing);               /**< Output: overall phasing */
+
   UNUSED(ret);
   prC("hp", hp);
   prC("hc", hc);
 
-  COMPLEX16 hp_expected = 2.06987e-23 - I*9.29351e-23;
-  COMPLEX16 hc_expected = -9.29438e-23 - I*2.06629e-23;
+  COMPLEX16 hp_expected = 2.06975e-23 - I * 9.29353e-23;
+  COMPLEX16 hc_expected = -9.29441e-23 - I * 2.06616e-23;
   const REAL8 eps = 1e-5;
 
   assert(
@@ -383,7 +382,7 @@ static void Test_XLALSimIMRPhenomP(void);
 static void Test_XLALSimIMRPhenomP(void) {
   printf("\n** Test_XLALSimIMRPhenomP: **\n");
 
-  REAL8 eta, chi_eff, chip, thetaJ, phiJ, alpha0;
+  REAL8 eta, chi_eff, chip, thetaJ, alpha0;
 
   REAL8 m1 = 10;
   REAL8 m2 = 40;
@@ -406,8 +405,7 @@ static void Test_XLALSimIMRPhenomP(void) {
       &chip,              /**< Output: Effective spin in the orbital plane */
       &eta,               /**< Output: Symmetric mass-ratio */
       &thetaJ,            /**< Output: Angle between J0 and line of sight (z-direction) */
-      &phiJ,              /**< Output: Angle of J0 in the plane of the sky */
-      &alpha0,            /**< Output: Initial value of alpha angle */
+      &alpha0,            /**< Output: Initial value of alpha angle (azimuthal precession angle) */
       m1_SI,              /**< Mass of companion 1 (kg) */
       m2_SI,              /**< Mass of companion 2 (kg) */
       f_ref,              /**< Reference GW frequency (Hz) */
@@ -435,7 +433,6 @@ static void Test_XLALSimIMRPhenomP(void) {
     chip,                     /**< Effective spin in the orbital plane */
     eta,                      /**< Symmetric mass-ratio */
     thetaJ,                   /**< Angle between J0 and line of sight (z-direction) */
-    phiJ,                     /**< Angle of J0 in the plane of the sky */
     m1_SI + m2_SI,            /**< Total mass of binary (kg) */
     distance,                 /**< Distance of source (m) */
     alpha0,                   /**< Initial value of alpha angle */
@@ -452,8 +449,9 @@ static void Test_XLALSimIMRPhenomP(void) {
   prC("hp", hp);
   prC("hc", hc);
 
-  COMPLEX16 hp_expected = 1.00825e-23 - I*5.79215e-23;
-  COMPLEX16 hc_expected = -5.7913e-23 - I*1.00782e-23;
+  COMPLEX16 hp_expected = -8.90294e-24 + I * 5.81145e-23;
+  COMPLEX16 hc_expected =  5.81059e-23 + I * 8.89877e-24;
+
   const REAL8 eps = 1e-5;
 
   assert(
@@ -493,15 +491,14 @@ static void Test_PhenomC_PhenomP(void) {
   REAL8 lnhaty = 0;
   REAL8 lnhatz = 1;
 
-  REAL8 chi_eff, chip, thetaJ, phiJ, alpha0;
+  REAL8 chi_eff, chip, thetaJ, alpha0;
 
   XLALSimIMRPhenomPCalculateModelParameters(
       &chi_eff,           /**< Output: Effective aligned spin */
       &chip,              /**< Output: Effective spin in the orbital plane */
       &eta,               /**< Output: Symmetric mass-ratio */
       &thetaJ,            /**< Output: Angle between J0 and line of sight (z-direction) */
-      &phiJ,              /**< Output: Angle of J0 in the plane of the sky */
-      &alpha0,            /**< Output: Initial value of alpha angle */
+      &alpha0,            /**< Output: Initial value of alpha angle (azimuthal precession angle) */
       m1_SI,              /**< Mass of companion 1 (kg) */
       m2_SI,              /**< Mass of companion 2 (kg) */
       f_ref,              /**< Starting GW frequency (Hz) */
@@ -519,7 +516,6 @@ static void Test_PhenomC_PhenomP(void) {
   printf("chip = %g\n", chip);
   printf("eta = %g\n", eta);
   printf("thetaJ = %g\n", thetaJ);
-  printf("phiJ = %g\n", phiJ);
 
   int ret = XLALSimIMRPhenomP(
     &hptilde,                 /**< Frequency-domain waveform h+ */
@@ -528,10 +524,9 @@ static void Test_PhenomC_PhenomP(void) {
     chip,                     /**< Effective spin in the orbital plane */
     eta,                      /**< Symmetric mass-ratio */
     thetaJ,                   /**< Angle between J0 and line of sight (z-direction) */
-    phiJ,                     /**< Angle of J0 in the plane of the sky */
     m1_SI + m2_SI,            /**< Total mass of binary (kg) */
     distance,                 /**< Distance of source (m) */
-    alpha0,                   /**< Initial value of alpha angle */
+    alpha0,                   /**< Initial value of alpha angle (azimuthal precession angle) */
     phic,                     /**< Orbital coalescence phase (rad) */
     deltaF,                   /**< Sampling frequency (Hz) */
     f_min,                    /**< Starting GW frequency (Hz) */
@@ -580,7 +575,7 @@ static void Test_PhenomC_PhenomP(void) {
 
   // Now compute match between PhenomC and PhenomP for this aligned configuration
   REAL8 match = MatchSI(&hptilde, &htildePC, f_min, f_max_prime, deltaF);
-  REAL8 match_expected = 0.999443;
+  REAL8 match_expected = 0.999465;
 
   const REAL8 eps = 1e-5;
 
@@ -598,7 +593,7 @@ static void Test_XLALSimIMRPhenomP_f_ref(void) {
   // For aligned spins f_ref should not change the waveform
   printf("\n** Test_XLALSimIMRPhenomP_f_ref: **\n");
 
-  REAL8 eta, chi_eff, chip, thetaJ, phiJ, alpha0;
+  REAL8 eta, chi_eff, chip, thetaJ, alpha0;
 
   REAL8 m1 = 10;
   REAL8 m2 = 40;
@@ -621,8 +616,7 @@ static void Test_XLALSimIMRPhenomP_f_ref(void) {
       &chip,              /**< Output: Effective spin in the orbital plane */
       &eta,               /**< Output: Symmetric mass-ratio */
       &thetaJ,            /**< Output: Angle between J0 and line of sight (z-direction) */
-      &phiJ,              /**< Output: Angle of J0 in the plane of the sky */
-      &alpha0,            /**< Output: Initial value of alpha angle */
+      &alpha0,            /**< Output: Initial value of alpha angle (azimuthal precession angle) */
       m1_SI,              /**< Mass of companion 1 (kg) */
       m2_SI,              /**< Mass of companion 2 (kg) */
       f_ref,              /**< Reference GW frequency (Hz) */
@@ -650,10 +644,9 @@ static void Test_XLALSimIMRPhenomP_f_ref(void) {
     chip,                     /**< Effective spin in the orbital plane */
     eta,                      /**< Symmetric mass-ratio */
     thetaJ,                   /**< Angle between J0 and line of sight (z-direction) */
-    phiJ,                     /**< Angle of J0 in the plane of the sky */
     m1_SI + m2_SI,            /**< Total mass of binary (kg) */
     distance,                 /**< Distance of source (m) */
-    alpha0,                   /**< Initial value of alpha angle */
+    alpha0,                   /**< Initial value of alpha angle (azimuthal precession angle) */
     phic,                     /**< Orbital coalescence phase (rad) */
     deltaF,                   /**< Sampling frequency (Hz) */
     f_min,                    /**< Starting GW frequency (Hz) */
@@ -676,8 +669,7 @@ static void Test_XLALSimIMRPhenomP_f_ref(void) {
       &chip,              /**< Output: Effective spin in the orbital plane */
       &eta,               /**< Output: Symmetric mass-ratio */
       &thetaJ,            /**< Output: Angle between J0 and line of sight (z-direction) */
-      &phiJ,              /**< Output: Angle of J0 in the plane of the sky */
-      &alpha0,            /**< Output: Initial value of alpha angle */
+      &alpha0,            /**< Output: Initial value of alpha angle (azimuthal precession angle) */
       m1_SI,              /**< Mass of companion 1 (kg) */
       m2_SI,              /**< Mass of companion 2 (kg) */
       f_ref,              /**< Reference GW frequency (Hz) */
@@ -701,10 +693,9 @@ static void Test_XLALSimIMRPhenomP_f_ref(void) {
     chip,                     /**< Effective spin in the orbital plane */
     eta,                      /**< Symmetric mass-ratio */
     thetaJ,                   /**< Angle between J0 and line of sight (z-direction) */
-    phiJ,                     /**< Angle of J0 in the plane of the sky */
     m1_SI + m2_SI,            /**< Total mass of binary (kg) */
     distance,                 /**< Distance of source (m) */
-    alpha0,                   /**< Initial value of alpha angle */
+    alpha0,                   /**< Initial value of alpha angle (azimuthal precession angle) */
     phic,                     /**< Orbital coalescence phase (rad) */
     deltaF,                   /**< Sampling frequency (Hz) */
     f_min,                    /**< Starting GW frequency (Hz) */
@@ -732,6 +723,7 @@ int main(int argc, char *argv[]) {
   UNUSED(argc);
   UNUSED(argv);
 
+#ifndef _OPENMP
   Test_alpha_epsilon();
   Test_XLALSimIMRPhenomPCalculateModelParameters();
   Test_PhenomC();
@@ -739,6 +731,15 @@ int main(int argc, char *argv[]) {
   Test_XLALSimIMRPhenomP();
   Test_PhenomC_PhenomP();
   Test_XLALSimIMRPhenomP_f_ref();
+#else
+  UNUSED(Test_alpha_epsilon);
+  UNUSED(Test_XLALSimIMRPhenomPCalculateModelParameters);
+  UNUSED(Test_PhenomC);
+  UNUSED(Test_PhenomPCore);
+  UNUSED(Test_XLALSimIMRPhenomP);
+  UNUSED(Test_PhenomC_PhenomP);
+  UNUSED(Test_XLALSimIMRPhenomP_f_ref);
+#endif
 
   printf("\nAll done!\n");
   return 0;
